@@ -11,16 +11,22 @@
 #'  pair. Only the upper triangle of the matrix is actually needed.
 #' @param fixed_species Fixed partial solution with species that are considered 
 #'  as given. Those species are not going to be changed during optimization.
-#' @param partial_solution An initial \code{matrix} of species presences and 
+#' @param partial_solution Can be either the result of a previous optimization 
+#' run (see \code{value}) or an (initial) \code{matrix} of species presences and 
 #'  absences for each site in the landscape. The total number of presences must
-#'  match the estimated species richness of each site.
+#'  match the estimated species richness of each site. If a result of a previous 
+#'  optimization is used, its \code{optimized_grid} is used as initial matrix and
+#'  its \code{error} data frame will be extended with the new iterations.
 #' @param max_iterations The maximum number of iterations that the optimization
 #'  algorithm may run through before stopping.
+#' @param autostop The optimizer will stop after this number of iterations with no
+#'  improvement. Default: \code{0} means auto stop is disabled.
 #' @param seed Seed for random number generator. Seed must be a positive integer value.
 #'   \code{seed = NA} means that a random integer is used as seed. 
 #' @param verbose If \code{TRUE} (default), a progress report is printed during
 #'  the optimization run. 
-#' @param interruptible Allow a run to be interrupted before completion.
+#' @param interruptible Allow a run to be interrupted before completion. 
+#' \code{FALSE} increases the performance.#' 
 #' 
 #' @details \code{run_optimization_min_conf} is the core function of the 
 #'  \code{spectre} package. The underlying algorithm of this function is
@@ -51,6 +57,7 @@ run_optimization_min_conf <- function(alpha_list,
                                       max_iterations,
                                       partial_solution = NULL,
                                       fixed_species = NULL,
+                                      autostop = 0,
                                       seed = NA,
                                       verbose = TRUE,
                                       interruptible = TRUE) {
@@ -59,8 +66,12 @@ run_optimization_min_conf <- function(alpha_list,
     fixed_species <- matrix()
   }
   
+  previous_iterations <- NA
   if (is.null(partial_solution)) {
     partial_solution <- matrix()
+  } else if (is.list(partial_solution)) {
+    previous_iterations <- partial_solution$error
+    partial_solution <- partial_solution$optimized_grid
   }
   
   if (is.na(seed)) {
@@ -75,9 +86,17 @@ run_optimization_min_conf <- function(alpha_list,
                               max_iterations = max_iterations,
                               partial_solution = partial_solution,
                               fixed_species = fixed_species,
+                              autostop = autostop,
                               seed = seed, 
                               verbose = verbose,
                               interruptible = interruptible)
   
+  if (length(previous_iterations) > 1) {
+    result$error <- rbind(previous_iterations, result$error[-1,])
+    result$error$i <- 0:(nrow(result$error) - 1)
+  }
+  
+  class(result) <- "optim_sol"
+  
   return(result)
 }
